@@ -31,5 +31,5 @@ def noop():
 
 
 def get_time_in_millis():
-    start_time = datetime.utcnow()
+    start_time = datetime.now()
     return '{0}.{1}'.format(int(start_time.timestamp()), int(start_time.microsecond / 1000))
